@@ -1,14 +1,11 @@
 package Data::DPath;
-# git description: v0.49-2-g286e675
+# git description: v0.50-7-gf0eb22a
 
 BEGIN {
   $Data::DPath::AUTHORITY = 'cpan:SCHWIGON';
 }
-{
-  $Data::DPath::VERSION = '0.50';
-}
 # ABSTRACT: DPath is not XPath!
-
+$Data::DPath::VERSION = '0.51';
 use 5.008;
 use strict;
 use warnings;
@@ -718,6 +715,26 @@ the first escaped double-quote is ok to be a single backslash.
 All strange, isn't it? At least it's (hopefully) consistent with
 something you know (Perl, Shell, etc.).
 
+=head2 XPath idioms
+
+Here are some typical XPath use-cases that can be achieved with
+Data::DPath, although a bit differently.
+
+=head3 Attribute access
+
+In XPath it's quite common to use a filter with attributes like this:
+
+ //AAA/BBB/*[@CCC="DDD"]
+
+A naive user could translate such a construct for Data::DPath like
+this:
+
+ //AAA/BBB/*[CCC eq "DDD"]
+
+except that it does not work. What works is this:
+
+ //AAA/BBB/*[key eq "CCC" && value eq "DDD"]
+
 =head1 Iterator style
 
 The I<iterator style> approach is an alternative to the already
@@ -850,7 +867,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steffen Schwigon.
+This software is copyright (c) 2015 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
