@@ -2,11 +2,8 @@ package Data::DPath::Context;
 BEGIN {
   $Data::DPath::Context::AUTHORITY = 'cpan:SCHWIGON';
 }
-{
-  $Data::DPath::Context::VERSION = '0.50';
-}
 # ABSTRACT: Abstraction for a current context that enables incremental searches
-
+$Data::DPath::Context::VERSION = '0.51';
 use strict;
 use warnings;
 
@@ -33,9 +30,7 @@ BEGIN {
 BEGIN {
   $Data::DPath::Filters::AUTHORITY = 'cpan:SCHWIGON';
 }
-{
-  $Data::DPath::Filters::VERSION = '0.50';
-}
+$Data::DPath::Filters::VERSION = '0.51';
         $COMPARTMENT = Safe->new;
         $COMPARTMENT->permit(qw":base_core");
         # map DPath filter functions into new namespace
@@ -105,7 +100,6 @@ sub _any
         return $out unless @$in;
 
         my @newin;
-        my @newout;
         my $tmp_ref;
         my $tmp_deref;
         my $tmp_reftype;
@@ -117,8 +111,15 @@ sub _any
 
                 # speed optimization: first try faster ref, then reftype
                 if (ref($$ref) eq HASH or reftype($$ref) eq HASH) {
-                        @values =
-                            map { { val_ref => \($$ref->{$_}), key => $_ } }
+                        push @$out,
+                            map {
+                                 my $newpoint = Point->new
+                                                     ->ref(\($$ref->{$_}))
+                                                     ->parent($point)
+                                                     ->attrs(Attrs->new(key => $_));
+                                 push @newin, $newpoint; # remember added points
+                                 $newpoint;
+                            }
                             grep {
                                     # speed optimization: only consider a key if lookahead looks promising
                                     not defined $lookahead_key
@@ -132,23 +133,18 @@ sub _any
                                 keys %{$$ref};
                 }
                 elsif (ref($$ref) eq ARRAY or reftype($$ref) eq ARRAY) {
-                        @values = map { { val_ref => \$_ } } @{$$ref}
+                        push @$out,
+                            map {
+                                my $newpoint = Point->new->ref($_->{val_ref})->parent($point);
+                                push @newin, $newpoint; # remember added points
+                                $newpoint;
+                            }
+                            map { { val_ref => \$_ } } @{$$ref}
                 }
                 else {
                         next
                 }
-
-                foreach (@values)
-                {
-                        my $key = $_->{key};
-                        my $val_ref = $_->{val_ref};
-                        my $newpoint = Point->new->ref($val_ref)->parent($point);
-                        $newpoint->attrs( Attrs->new(key => $key)) if $key;
-                        push @newout, $newpoint;
-                        push @newin,  $newpoint;
-                }
         }
-        push @$out, @newout;
         return _any ($out, \@newin, $lookahead_key);
 }
 
@@ -585,7 +581,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steffen Schwigon.
+This software is copyright (c) 2015 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
